# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.0

import enum

import winrt.system
from winrt._winrt_windows_devices_wifi import (
    WiFiAdapter,
    WiFiAvailableNetwork,
    WiFiConnectionResult,
    WiFiNetworkReport,
    WiFiOnDemandHotspotConnectTriggerDetails,
    WiFiOnDemandHotspotConnectionResult,
    WiFiOnDemandHotspotNetwork,
    WiFiOnDemandHotspotNetworkProperties,
    WiFiWpsConfigurationResult,
)

__all__ = [
    "WiFiAccessStatus",
    "WiFiConnectionMethod",
    "WiFiConnectionStatus",
    "WiFiNetworkKind",
    "WiFiOnDemandHotspotAvailability",
    "WiFiOnDemandHotspotCellularBars",
    "WiFiOnDemandHotspotConnectStatus",
    "WiFiPhyKind",
    "WiFiReconnectionKind",
    "WiFiWpsConfigurationStatus",
    "WiFiWpsKind",
    "WiFiAdapter",
    "WiFiAvailableNetwork",
    "WiFiConnectionResult",
    "WiFiNetworkReport",
    "WiFiOnDemandHotspotConnectTriggerDetails",
    "WiFiOnDemandHotspotConnectionResult",
    "WiFiOnDemandHotspotNetwork",
    "WiFiOnDemandHotspotNetworkProperties",
    "WiFiWpsConfigurationResult",
]

class WiFiAccessStatus(enum.IntEnum):
    UNSPECIFIED = 0
    ALLOWED = 1
    DENIED_BY_USER = 2
    DENIED_BY_SYSTEM = 3

class WiFiConnectionMethod(enum.IntEnum):
    DEFAULT = 0
    WPS_PIN = 1
    WPS_PUSH_BUTTON = 2

class WiFiConnectionStatus(enum.IntEnum):
    UNSPECIFIED_FAILURE = 0
    SUCCESS = 1
    ACCESS_REVOKED = 2
    INVALID_CREDENTIAL = 3
    NETWORK_NOT_AVAILABLE = 4
    TIMEOUT = 5
    UNSUPPORTED_AUTHENTICATION_PROTOCOL = 6

class WiFiNetworkKind(enum.IntEnum):
    ANY = 0
    INFRASTRUCTURE = 1
    ADHOC = 2

class WiFiOnDemandHotspotAvailability(enum.IntEnum):
    AVAILABLE = 0
    UNAVAILABLE = 1

class WiFiOnDemandHotspotCellularBars(enum.IntEnum):
    ZERO_BARS = 0
    ONE_BAR = 1
    TWO_BARS = 2
    THREE_BARS = 3
    FOUR_BARS = 4
    FIVE_BARS = 5

class WiFiOnDemandHotspotConnectStatus(enum.IntEnum):
    UNSPECIFIED_FAILURE = 0
    SUCCESS = 1
    APP_TIMED_OUT = 2
    INVALID_CREDENTIAL = 3
    NETWORK_NOT_AVAILABLE = 4
    UNSUPPORTED_AUTHENTICATION_PROTOCOL = 5
    BLUETOOTH_CONNECT_FAILED = 6
    BLUETOOTH_TRANSMISSION_ERROR = 7
    OPERATION_CANCELED_BY_USER = 8
    ENTITLEMENT_CHECK_FAILED = 9
    NO_CELLULAR_SIGNAL = 10
    CELLULAR_DATA_TURNED_OFF = 11
    WLAN_CONNECT_FAILED = 12
    WLAN_NOT_VISIBLE = 13
    ACCESS_POINT_CANNOT_CONNECT = 14
    CELLULAR_CONNECT_TIMED_OUT = 15
    ROAMING_NOT_ALLOWED = 16
    PAIRING_REQUIRED = 17
    DATA_LIMIT_REACHED = 18

class WiFiPhyKind(enum.IntEnum):
    UNKNOWN = 0
    FHSS = 1
    DSSS = 2
    IR_BASEBAND = 3
    OFDM = 4
    HRDSSS = 5
    ERP = 6
    HT = 7
    VHT = 8
    DMG = 9
    HE = 10
    EHT = 11

class WiFiReconnectionKind(enum.IntEnum):
    AUTOMATIC = 0
    MANUAL = 1

class WiFiWpsConfigurationStatus(enum.IntEnum):
    UNSPECIFIED_FAILURE = 0
    SUCCESS = 1
    TIMEOUT = 2

class WiFiWpsKind(enum.IntEnum):
    UNKNOWN = 0
    PIN = 1
    PUSH_BUTTON = 2
    NFC = 3
    ETHERNET = 4
    USB = 5

